summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete/kopetepicture.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/libkopete/kopetepicture.cpp')
-rw-r--r--kopete/libkopete/kopetepicture.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/kopete/libkopete/kopetepicture.cpp b/kopete/libkopete/kopetepicture.cpp
index 1336492f..11e067cb 100644
--- a/kopete/libkopete/kopetepicture.cpp
+++ b/kopete/libkopete/kopetepicture.cpp
@@ -27,7 +27,7 @@
namespace Kopete
{
-class Picture::Private : public KShared
+class Picture::Private : public TDEShared
{
public:
Private()
@@ -186,7 +186,7 @@ void Picture::setPicture(const KABC::Picture &picture)
void Picture::detach()
{
// there is no detach in KSharedPtr.
if( d.count() == 1 )
return;
@@ -186,7 +186,7 @@ void Picture::setPicture(const KABC::Picture &picture)
void Picture::detach()
{
- // there is no detach in KSharedPtr.
+ // there is no detach in TDESharedPtr.
if( d.count() == 1 )
return;